// Zmienne globalne
let currentCategory = 'frekwencja';
let currentClass = '';
let studentsData = [];
let currentDay = 0;
let currentRole = "teacher"
let currentRoleCriterias = []
const baseDate = new Date();

function generateTable(category) {
    const table = document.getElementById('student-table');
    const thead = table.querySelector('thead tr');
    const tbody = table.querySelector('tbody');

    // Wyczyść istniejące nagłówki i wiersze
    thead.innerHTML = '';
    tbody.innerHTML = '';

    // Dodaj nagłówek 'Imię i Nazwisko'
    const thName = document.createElement('th');
    thName.textContent = "Imię i Nazwisko";
    thead.appendChild(thName);

    // Pobierz kolumny dla wybranej kategorii
    const categoryColumns = categories[category];

    // Dodaj nagłówki dla kryteriów w kategorii
    categoryColumns.forEach(column => {
        const th = document.createElement('th');
        th.textContent = column.name;
        thead.appendChild(th);
    });

    // Generuj wiersze dla uczniów
    studentsData.forEach(student => {
        const row = document.createElement('tr');

        // Komórka z imieniem i nazwiskiem
        const tdName = document.createElement('td');
        tdName.textContent = `${student.first_name} ${student.last_name}`;
        row.appendChild(tdName);

        // Upewnij się, że 'behavior' jest zdefiniowany
        if (!student.behavior) {
            student.behavior = {};
        }

        // Komórki z checkboxami dla kryteriów
        categoryColumns.forEach(column => {
            const td = document.createElement('td');
            const checkbox = document.createElement('input');
            checkbox.type = 'checkbox';
            const studentId = `${student.first_name}-${student.last_name}`.replace(/ /g, '-');
            checkbox.id = `${column.id}-${studentId}`;
            checkbox.onchange = calculateStats;

            // Ustawienie stanu checkboxa na podstawie zapisanych danych
            checkbox.checked = student.behavior[`day${currentDay}`]?.[column.id] || false;

            td.appendChild(checkbox);
            row.appendChild(td);
        });

        tbody.appendChild(row);
    });
}
// Funkcja do wczytywania pliku JSON
async function fetchJSONFile(filePath) {
    try {
        const response = await fetch(filePath);
        if (!response.ok) {
            throw new Error(`Błąd HTTP! Status: ${response.status}`);
        }
        return await response.json();
    } catch (error) {
        console.error("Błąd podczas pobierania pliku JSON:", error);
        return null;
    }
}

// Obiekt do przechowywania danych klas i uczniów
const classData = {};

// Funkcja do wczytania pliku class.json i danych uczniów
async function loadClasses() {
    const classFilePath = '/data/class.json';
    const classes = await fetchJSONFile(classFilePath);

    if (classes) {
        console.log('Załadowane klasy:', classes);

        const selectClass = document.getElementById("select-class-select");
        selectClass.innerHTML = ""; // Wyczyść istniejące opcje

        classes.forEach(classInfo => {
            const option = document.createElement('option');
            option.value = classInfo.file_path;
            option.textContent = `Klasa: ${classInfo.class}`;
            selectClass.appendChild(option);
            console.log("Dodano klasę ", classInfo.class, " do SELECT");
        });

        // Dodaj nasłuchiwacz zdarzeń na zmianę wyboru klasy
        selectClass.addEventListener('change', function() {
            const selectedClassFile = this.value;
            console.log(`Wybrano klasę: ${selectedClassFile}`);
            loadStudents(selectedClassFile);
        });

        // Opcjonalnie, ustaw domyślnie pierwszą klasę i załaduj jej uczniów
        if (classes.length > 0) {
            selectClass.selectedIndex = 0;
            const defaultClassFile = classes[0].file_path;
            loadStudents(defaultClassFile);
        }
    }
}

// Funkcja do wczytania danych uczniów dla wybranej klasy
async function loadStudents(classFilePath) {
    if (!classFilePath) {
        console.warn("Nie wybrano żadnej klasy.");
        return;
    }

    const studentsFilePath = `/data/${classFilePath}`;
    const data = await fetchJSONFile(studentsFilePath);

    if (data && Array.isArray(data.students)) {
        console.log(`Uczniowie załadowani z pliku ${classFilePath}:`, data);
        studentsData = data.students; // Aktualizuj globalną tablicę uczniów

        // Inicjalizacja 'behavior' dla każdego ucznia, jeśli jest niezdefiniowany
        studentsData.forEach(student => {
            if (!student.behavior) {
                student.behavior = {};
            }
        });

        currentClass = classFilePath; // Ustaw aktualną klasę
        generateTable(currentCategory); // Regeneruj tabelę z aktualną kategorią
    } else {
        console.error("Błąd: Nie udało się załadować danych uczniów lub dane są niepoprawne.");
        studentsData = []; // Jeśli nie udało się załadować danych, wyczyść tablicę uczniów
        currentClass = '';
        generateTable(currentCategory); // Regeneruj pustą tabelę
    }
}

async function getCategoriesWithCriteria() {
    const criteriaFilePath = '/data/criteria.json';
    const criteria = await fetchJSONFile(criteriaFilePath);
    let categoriesWithCriteria = {}
    
    criteria.categories.forEach(category => {
        let criteriaForCategory = []
        criteria.criteria.forEach(criteria => {
            if(category.criteria_ids.includes(criteria.id)) {
                //console.log(`!!! ${category.name} posiada ${criteria.name}`)
                criteriaForCategory.push({name: criteria.name, id: criteria.id})
            }
        })
        categoriesWithCriteria[category.id] = criteriaForCategory
    })

    return categoriesWithCriteria

    
}

// Funkcja do wczytania pliku criteria.json
async function loadCriteria() {
    const criteriaFilePath = '/data/criteria.json';
    const criteria = await fetchJSONFile(criteriaFilePath);

    console.log("Załadowane kryteria:", criteria);
    
    //
    // LADOWANIE ROL
    //
    const roles = criteria.roles;
    
    const selectroleByid = document.getElementById("select-role");
    let selectroleHTML = ""; // Zainicjalizuj pusty string na HTML
    currentRole = "teacher"
    // Iteracja przez klucze obiektu roles
    for (const [key, value] of Object.entries(roles)) {
        if(key == "teacher") {
            currentRoleCriterias = value.criteria_ids
        }
        selectroleHTML += `<option value="${key}">${value.name}</option>`;
    }

    // Wstawienie HTML do elementu select
    selectroleByid.innerHTML = selectroleHTML;

    // category-buttons-box
    const categoriesCriteria = criteria.categories;
    const categoryButtonsBox = document.getElementById("category-buttons-box");
    let categoryButtonHTML = ""
    categoriesCriteria.forEach(category => {
        const hasCriteria = category.criteria_ids.some(criteriaId => currentRoleCriterias.includes(criteriaId));
        
        // Jeśli kategoria ma kryteria, dodajemy przycisk
        if (hasCriteria) {
            categoryButtonHTML += `<button data-category="${category.id}" onclick="showInnerTab('${category.id}')">${category.name}</button>`;
        }
    });

    categoryButtonsBox.innerHTML = categoryButtonHTML;
}

async function changeRole(role) {
    const select = document.getElementById('select-role');
    const selectedValue = select.value;

    const criteriaFilePath = '/data/criteria.json';
    const criteria = await fetchJSONFile(criteriaFilePath);

    currentRole = selectedValue
    currentRoleCriterias = criteria.roles[currentRole].criteria_ids
    console.log("currentRole:", currentRole)
    console.log("currentRoleCriterias:", currentRoleCriterias)

    // category-buttons-box
    const categoriesCriteria = criteria.categories;
    const categoryButtonsBox = document.getElementById("category-buttons-box");
    let categoryButtonHTML = ""
    categoriesCriteria.forEach(category => {
        const hasCriteria = category.criteria_ids.some(criteriaId => currentRoleCriterias.includes(criteriaId));

        
        // Jeśli kategoria ma kryteria, dodajemy przycisk
        if (hasCriteria) {
            categoryButtonHTML += `<button data-category="${category.id}" onclick="showInnerTab('${category.id}')">${category.name}</button>`;
        }
    });

    categoryButtonsBox.innerHTML = categoryButtonHTML;

    generateTable(currentCategory)
}

// Funkcja do przełączania głównych zakładek
function showTab(tabName) {
    // Ukryj wszystkie główne taby
    const tabs = document.querySelectorAll('.tab');
    tabs.forEach(tab => tab.classList.remove('active'));

    // Pokaż wybrany tab
    const selectedTab = document.getElementById(tabName);
    if (selectedTab) {
        selectedTab.classList.add('active');
    }

    if (tabName === 'criteria') {
        loadDayData();
    } else if (tabName === 'points') {
        calculateStats();
    }
}

// Funkcja do przełączania kategorii w tabeli uczniów
function showInnerTab(category) {
    currentCategory = category;
    // Generowanie tabeli na podstawie wybranej kategorii
    generateTable(category);

    // Podkreślenie aktywnego przycisku
    const buttons = document.querySelectorAll('.category-buttons button');
    buttons.forEach(button => button.classList.remove('active'));
    const activeButton = document.querySelector(`.category-buttons button[data-category="${category}"]`);
    if (activeButton) {
        activeButton.classList.add('active');
    }
}

// Funkcja, aby ustawić domyślną kategorię i zakładkę
document.addEventListener("DOMContentLoaded", function() {
    // Domyślnie pokazujemy kategorię 'frekwencja'
   

    // Ustawienie daty na dziś
    document.getElementById('current-date').innerText = baseDate.toLocaleDateString();

    // Uruchomienie wczytywania klas i kryteriów
    loadClasses();
    loadCriteria();

    showInnerTab('frekwencja');
});

// Funkcja do zmiany dnia
function changeDay(direction) {
    saveDayData();
    currentDay += direction;
    const newDate = new Date(baseDate);
    newDate.setDate(baseDate.getDate() + currentDay);
    document.getElementById('current-date').innerText = newDate.toLocaleDateString();
    loadDayData();
}

// Funkcja do ładowania danych dnia
function loadDayData() {
    studentsData.forEach(student => {
        const studentId = `${student.first_name}-${student.last_name}`.replace(/ /g, '-');
        const behavior = student.behavior[`day${currentDay}`] || {};

        // Pobierz kryteria dla aktualnej kategorii
        const categoryColumns = categories[currentCategory];
        categoryColumns.forEach(column => {
            const checkbox = document.getElementById(`${column.id}-${studentId}`);
            if (checkbox) {
                checkbox.checked = behavior[column.id] || false;
            }
        });
    });

    calculateStats();
}

// Funkcja do zapisywania danych dnia
function saveDayData() {
    studentsData.forEach(student => {
        const studentId = `${student.first_name}-${student.last_name}`.replace(/ /g, '-');

        // Upewnij się, że 'behavior' jest zdefiniowany
        if (!student.behavior) {
            student.behavior = {};
        }

        let behavior = student.behavior[`day${currentDay}`] || {};

        const categoryColumns = categories[currentCategory];

        categoryColumns.forEach(column => {
            const checkbox = document.getElementById(`${column.id}-${studentId}`);
            if (checkbox) {
                behavior[column.id] = checkbox.checked;
            }
        });

        student.behavior[`day${currentDay}`] = behavior;
    });
}

// Funkcja do obliczania statystyk
function calculateStats() {
    // Pobieranie punktów z zakładki "Ustal punkty"
    const points = {
        frekwencja: parseInt(document.getElementById('frekwencja-punkty').value) || 0,
        brak_godzin: parseInt(document.getElementById('brak_godzin-punkty').value) || 0,
        min_85: parseInt(document.getElementById('min_85-punkty').value) || 0,
        etap_szkolny: parseInt(document.getElementById('etap_szkolny-punkty').value) || 5,
        etap_rejonowy: parseInt(document.getElementById('etap_rejonowy-punkty').value) || 10,
        etap_wojewodzki: parseInt(document.getElementById('etap_wojewodzki-punkty').value) || 15,
        etap_ogolnopolski: parseInt(document.getElementById('etap_ogolnopolski-punkty').value) || 20,
        udzial_konkurs: parseInt(document.getElementById('udzial_konkurs-punkty').value) || 5,
        wyroznienie_konkurs: parseInt(document.getElementById('wyroznienie_konkurs-punkty').value) || 10,
        reprezentacja_indywidualna: parseInt(document.getElementById('reprezentacja_indywidualna-punkty').value) || 5,
        reprezentacja_zespolowa: parseInt(document.getElementById('reprezentacja_zespolowa-punkty').value) || 10,
        udzial_zawody: parseInt(document.getElementById('udzial_zawody-punkty').value) || 15,
        organizacja_imprez: parseInt(document.getElementById('organizacja_imprez-punkty').value) || 10,
        funkcja_klasa: parseInt(document.getElementById('funkcja_klasa-punkty').value) || 10,
        uroczystosci: parseInt(document.getElementById('uroczystosci-punkty').value) || 10,
        poczta_sztandar: parseInt(document.getElementById('poczta_sztandar-punkty').value) || 20,
        pomoc_nauczyciel: parseInt(document.getElementById('pomoc_nauczyciel-punkty').value) || 10,
        wolontariat: parseInt(document.getElementById('wolontariat-punkty').value) || 10
    };

    let stats = '';

    studentsData.forEach(student => {
        let totalPoints = 0;

        Object.keys(student.behavior).forEach(day => {
            const behavior = student.behavior[day];

            let dayPoints = 0;
            for (const [criterion, value] of Object.entries(behavior)) {
                if (value && points[criterion]) {
                    dayPoints += points[criterion];
                }
            }

            totalPoints += dayPoints;
        });

        stats += `${student.first_name} ${student.last_name}: ${totalPoints} punktów (${getGrade(totalPoints)})\n`;
    });

    document.getElementById('stats-output').innerText = stats;
}

// Funkcja do przypisywania ocen na podstawie punktów
function getGrade(points) {
    if (points >= 250) return "Wzorowe";
    if (points >= 180) return "Bardzo dobre";
    if (points >= 100) return "Dobre";
    if (points >= 50) return "Poprawne";
    if (points >= 0) return "Nieodpowiednie";
    return "Naganne";
}

// Funkcja do generowania tabeli uczniów na podstawie wybranej kategorii
async function generateTable(category) {
    const table = document.getElementById('student-table');
    const thead = table.querySelector('thead tr');
    const tbody = table.querySelector('tbody');

    // Wyczyść istniejące nagłówki i wiersze
    thead.innerHTML = '';
    tbody.innerHTML = '';

    // Dodaj nagłówek 'Imię i Nazwisko'
    const thName = document.createElement('th');
    thName.textContent = "Imię i Nazwisko";
    thead.appendChild(thName);

    // get role
    console.log("currentRole", currentRole)

    // Pobierz kolumny dla wybranej kategorii
    const categories = await getCategoriesWithCriteria()
    console.log("łot:", categories)
    const categoryColumns = categories[category];

    // Dodaj nagłówki dla kryteriów w kategorii
    categoryColumns.forEach(column => {
        const th = document.createElement('th');
        if(currentRoleCriterias.includes(column.id)) {
            th.textContent = column.name;
            thead.appendChild(th);
        }
        
        
    });

    // Generuj wiersze dla uczniów
    studentsData.forEach(student => {
        const row = document.createElement('tr');

        // Komórka z imieniem i nazwiskiem
        const tdName = document.createElement('td');
        tdName.textContent = `${student.first_name} ${student.last_name}`;
        row.appendChild(tdName);

        // Upewnij się, że 'behavior' jest zdefiniowany
        if (!student.behavior) {
            student.behavior = {};
        }

        // Komórki z checkboxami dla kryteriów
        categoryColumns.forEach(column => {
            if(currentRoleCriterias.includes(column.id)) {
                const td = document.createElement('td');
                const checkbox = document.createElement('input');
                checkbox.type = 'checkbox';
                const studentId = `${student.first_name}-${student.last_name}`.replace(/ /g, '-');
                checkbox.id = `${column.id}-${studentId}`;
                checkbox.onchange = calculateStats;

                // Ustawienie stanu checkboxa na podstawie zapisanych danych
                checkbox.checked = student.behavior[`day${currentDay}`]?.[column.id] || false;

                td.appendChild(checkbox);
                row.appendChild(td);
                }
        });

        tbody.appendChild(row);
    });
}
function showTab(tabName) {
    // Ukryj wszystkie zakładki
    const tabs = document.querySelectorAll('.tab');
    tabs.forEach(tab => tab.classList.remove('active'));

    // Pokaż wybraną zakładkę
    const selectedTab = document.getElementById(tabName);
    if (selectedTab) {
        selectedTab.classList.add('active');
    }

    // Zmieniaj tytuł nagłówka w zależności od wybranej zakładki
    const headerTitle = document.getElementById('header-title');
    const upButtonContainer = document.getElementById('up-button-container');
    const selectRoleContainer = document.getElementById('select-role-container');
    const selectClassContainer = document.getElementById('select-class-container');

    switch (tabName) {
        case 'criteria':
            headerTitle.textContent = 'Ocena Zachowania';
            generateTable(currentCategory); // Generuj tabelę dla aktualnej kategorii
            upButtonContainer.style.display = 'block'; // Pokaż przyciski
            selectRoleContainer.style.display = 'block'; // Pokaż wybór roli
            selectClassContainer.style.display = 'block'; // Pokaż wybór klasy
            break;
        case 'stats':
            headerTitle.textContent = 'Statystyka';
            upButtonContainer.style.display = 'none'; // Ukryj przyciski
            selectRoleContainer.style.display = 'none'; // Ukryj wybór roli
            selectClassContainer.style.display = 'none'; // Ukryj wybór klasy
            break;
        case 'points':
            headerTitle.textContent = 'Ustal punkty';
            upButtonContainer.style.display = 'none'; // Ukryj przyciski
            selectRoleContainer.style.display = 'none'; // Ukryj wybór roli
            selectClassContainer.style.display = 'none'; // Ukryj wybór klasy
            break;
        default:
            headerTitle.textContent = 'Ocena Zachowania';
            upButtonContainer.style.display = 'none'; // Ukryj przyciski
            selectRoleContainer.style.display = 'none'; // Ukryj wybór roli
            selectClassContainer.style.display = 'none'; // Ukryj wybór klasy
    }
}

